@@ -72,7 +72,8 @@ def main(args=None):
         action="store_true",
         help=(
             "Launch a background wineserver process to improve Wine command "
-            "startup time. Default if bwrap is enabled."
+            "startup time. Disabled by default, as it can cause problems with "
+            "some graphical applications."
         )
     )
     parser.add_argument(
@@ -81,7 +82,7 @@ def main(args=None):
         action="store_false",
         help=(
             "Do not launch a background wineserver process to improve Wine "
-            "command startup time. Default if bwrap is not enabled."
+            "command startup time."
         )
     )
     parser.add_argument(
